==> GotoBLAS-1.00.tar.gz: GotoBLAS/level2/her/zher_k.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include <stdio.h>
#include <ctype.h>
#include "common.h"

#ifdef SYR_P1
#define ZHER_P1	((SYR_P1) / 2)
#endif

int CNAME(long m, FLOAT alpha, FLOAT *x,
		      long incx, FLOAT *a, long lda, FLOAT *buffer){

  long i, is;
  long min_i;
  FLOAT *p;

  for(is = 0; is < m; is += ZHER_P1){
    min_i = MIN(ZHER_P1, m - is);
      
    p = x + is * 2;

    if (incx != 1){
      for (i = 0; i < min_i; i++){
	buffer[i * 2 + 0] = x[(is + i) * incx * 2 + 0];
	buffer[i * 2 + 1] = x[(is + i) * incx * 2 + 1];
      }
      p = buffer;
    }

#ifndef LOWER
    for (i = 0; i < min_i; i++){
      ZAXPY_K(i + 1, 0, 0, 
	     alpha * p[i * 2 + 0], - alpha * p[i * 2 + 1],
	     p, 1, &a[(is + (i + is) * lda) * 2], 1, NULL, 0);
      a[(is + i + (i + is) * lda) * 2 + 1] = ZERO;
    }
    
    if (m - is > ZHER_P1){
      ZGERC_K(min_i, m - is - ZHER_P1, 0, alpha, ZERO,
	    p                         , 1,
	    x +        (is + ZHER_P1) * incx * 2, incx, 
	    a + (is  + (is + ZHER_P1) * lda) * 2,  lda, buffer + SUB_BUFFER_OFFSET);
    }
    
#else
    if (is > 0){
      ZGERC_K(min_i, is, 0, alpha, ZERO, p, 1, x, incx, a + is * 2, lda,
	    buffer + SUB_BUFFER_OFFSET);
    }
    
    for (i = 0; i < min_i; i++){
      ZAXPY_K(min_i - i, 0, 0,
	     alpha * p[i * 2 + 0], - alpha * p[i * 2 + 1],
	     p + i * 2, 1,
	     &a[((i + is) + (i + is) * lda) * 2], 1, NULL, 0);
      a[(is + i + (i + is) * lda) * 2 + 1] = ZERO;
    }
#endif
  }

  return 0;
}

==> GotoBLAS-1.10.tar.gz: GotoBLAS/level2/her/zher_k.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include "common.h"

int CNAME(long m, FLOAT alpha, FLOAT *x,
		      long incx, FLOAT *a, long lda, FLOAT *buffer){

  long i;
  FLOAT *X;

  X = x;
  lda *= 2;

  if (incx != 1) {
    ZCOPY_K(m, x, incx, buffer, 1);
    X = buffer;
  }

  for (i = 0; i < m; i++){
#ifndef LOWER
    ZAXPY_K(i + 1, 0, 0, alpha * X[i * 2 + 0], -alpha * X[i * 2 + 1], X,         1, a, 1, NULL, 0);
    a[i * 2 + 1] = ZERO;
    a += lda;
#else
    ZAXPY_K(m - i, 0, 0, alpha * X[i * 2 + 0], -alpha * X[i * 2 + 1], X + i * 2, 1, a, 1, NULL, 0);
    a[1] = ZERO;
    a += 2 + lda;
#endif
    }

  return 0;
}
